# coding: utf-8

# flake8: noqa
"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


if __import__("typing").TYPE_CHECKING:
    # import models into model package
    from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest
    from neurograph.v1.models.auth_service_token_response import AuthServiceTokenResponse
    from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest
    from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse
    from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse
    from neurograph.v1.models.client_client import ClientClient
    from neurograph.v1.models.client_client_get_detail_response import ClientClientGetDetailResponse
    from neurograph.v1.models.client_client_get_many_response import ClientClientGetManyResponse
    from neurograph.v1.models.client_client_info import ClientClientInfo
    from neurograph.v1.models.client_client_metadata_request import ClientClientMetadataRequest
    from neurograph.v1.models.client_client_metadata_response import ClientClientMetadataResponse
    from neurograph.v1.models.client_client_personas_response import ClientClientPersonasResponse
    from neurograph.v1.models.client_client_url_snapshot_response import ClientClientURLSnapshotResponse
    from neurograph.v1.models.client_client_url_snapshot_row import ClientClientURLSnapshotRow
    from neurograph.v1.models.client_client_upsert_request import ClientClientUpsertRequest
    from neurograph.v1.models.client_client_upsert_response import ClientClientUpsertResponse
    from neurograph.v1.models.client_client_url_row import ClientClientUrlRow
    from neurograph.v1.models.client_client_url_upsert_request import ClientClientUrlUpsertRequest
    from neurograph.v1.models.client_client_url_upsert_response import ClientClientUrlUpsertResponse
    from neurograph.v1.models.client_client_urls_response import ClientClientUrlsResponse
    from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest
    from neurograph.v1.models.client_kpi import ClientKpi
    from neurograph.v1.models.client_metadata import ClientMetadata
    from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand
    from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail
    from neurograph.v1.models.client_persona import ClientPersona
    from neurograph.v1.models.client_persona_factor import ClientPersonaFactor
    from neurograph.v1.models.client_persona_insight import ClientPersonaInsight
    from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait
    from neurograph.v1.models.client_probe import ClientProbe
    from neurograph.v1.models.client_probe_todo_row import ClientProbeTodoRow
    from neurograph.v1.models.client_query import ClientQuery
    from neurograph.v1.models.client_trigger_probe_response import ClientTriggerProbeResponse
    from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig
    from neurograph.v1.models.dagster_dagster_info import DagsterDagsterInfo
    from neurograph.v1.models.dagster_dagster_log_create_request import DagsterDagsterLogCreateRequest
    from neurograph.v1.models.dagster_dagster_log_create_response import DagsterDagsterLogCreateResponse
    from neurograph.v1.models.dagster_dagster_log_get_response import DagsterDagsterLogGetResponse
    from neurograph.v1.models.db_client_url import DbClientUrl
    from neurograph.v1.models.db_knowledge_customer import DbKnowledgeCustomer
    from neurograph.v1.models.db_knowledge_order import DbKnowledgeOrder
    from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct
    from neurograph.v1.models.db_knowledge_store import DbKnowledgeStore
    from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams
    from neurograph.v1.models.knowledge_assertion import KnowledgeAssertion
    from neurograph.v1.models.knowledge_assertion_create_request import KnowledgeAssertionCreateRequest
    from neurograph.v1.models.knowledge_assertion_list_response import KnowledgeAssertionListResponse
    from neurograph.v1.models.knowledge_assertion_query import KnowledgeAssertionQuery
    from neurograph.v1.models.knowledge_assertion_response import KnowledgeAssertionResponse
    from neurograph.v1.models.knowledge_customer_query import KnowledgeCustomerQuery
    from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse
    from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact
    from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest
    from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse
    from neurograph.v1.models.knowledge_enrichment_artifact_response import KnowledgeEnrichmentArtifactResponse
    from neurograph.v1.models.knowledge_enrichment_artifact_update_output_request import KnowledgeEnrichmentArtifactUpdateOutputRequest
    from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest
    from neurograph.v1.models.knowledge_enrichment_query import KnowledgeEnrichmentQuery
    from neurograph.v1.models.knowledge_entity import KnowledgeEntity
    from neurograph.v1.models.knowledge_entity_create_request import KnowledgeEntityCreateRequest
    from neurograph.v1.models.knowledge_entity_create_response import KnowledgeEntityCreateResponse
    from neurograph.v1.models.knowledge_entity_extra import KnowledgeEntityExtra
    from neurograph.v1.models.knowledge_entity_get_many_response import KnowledgeEntityGetManyResponse
    from neurograph.v1.models.knowledge_entity_in_db import KnowledgeEntityInDb
    from neurograph.v1.models.knowledge_entity_relations import KnowledgeEntityRelations
    from neurograph.v1.models.knowledge_entity_schema import KnowledgeEntitySchema
    from neurograph.v1.models.knowledge_entity_schema_row import KnowledgeEntitySchemaRow
    from neurograph.v1.models.knowledge_entity_schema_upsert_request import KnowledgeEntitySchemaUpsertRequest
    from neurograph.v1.models.knowledge_entity_schemas_response import KnowledgeEntitySchemasResponse
    from neurograph.v1.models.knowledge_entity_schemas_upsert_response import KnowledgeEntitySchemasUpsertResponse
    from neurograph.v1.models.knowledge_entity_type_row import KnowledgeEntityTypeRow
    from neurograph.v1.models.knowledge_entity_upsert_request import KnowledgeEntityUpsertRequest
    from neurograph.v1.models.knowledge_entity_upsert_row import KnowledgeEntityUpsertRow
    from neurograph.v1.models.knowledge_err_entity_row import KnowledgeErrEntityRow
    from neurograph.v1.models.knowledge_ingest_raw_request import KnowledgeIngestRawRequest
    from neurograph.v1.models.knowledge_ingest_raw_response import KnowledgeIngestRawResponse
    from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow
    from neurograph.v1.models.knowledge_kind_response import KnowledgeKindResponse
    from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery
    from neurograph.v1.models.knowledge_order_response import KnowledgeOrderResponse
    from neurograph.v1.models.knowledge_product_query import KnowledgeProductQuery
    from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse
    from neurograph.v1.models.knowledge_query import KnowledgeQuery
    from neurograph.v1.models.knowledge_store_query import KnowledgeStoreQuery
    from neurograph.v1.models.knowledge_store_response import KnowledgeStoreResponse
    from neurograph.v1.models.knowledge_type_response import KnowledgeTypeResponse
    from neurograph.v1.models.lookup_language import LookupLanguage
    from neurograph.v1.models.lookup_lookup_language_response import LookupLookupLanguageResponse
    from neurograph.v1.models.lookup_lookup_state_response import LookupLookupStateResponse
    from neurograph.v1.models.lookup_state import LookupState
    from neurograph.v1.models.lookup_state_response import LookupStateResponse
    from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse
    from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest
    from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest
    from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse
    from neurograph.v1.models.organizations_metadata import OrganizationsMetadata
    from neurograph.v1.models.organizations_organization import OrganizationsOrganization
    from neurograph.v1.models.organizations_organization_brand import OrganizationsOrganizationBrand
    from neurograph.v1.models.organizations_organization_create_request import OrganizationsOrganizationCreateRequest
    from neurograph.v1.models.organizations_organization_detail_response import OrganizationsOrganizationDetailResponse
    from neurograph.v1.models.organizations_organization_get_many_response import OrganizationsOrganizationGetManyResponse
    from neurograph.v1.models.organizations_organization_metadata_request import OrganizationsOrganizationMetadataRequest
    from neurograph.v1.models.organizations_organization_metadata_response import OrganizationsOrganizationMetadataResponse
    from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest
    from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse
    from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest
    from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig
    from neurograph.v1.models.personas_delete_many_persona_instances_request import PersonasDeleteManyPersonaInstancesRequest
    from neurograph.v1.models.personas_kpi import PersonasKpi
    from neurograph.v1.models.personas_match_criteria_row import PersonasMatchCriteriaRow
    from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn
    from neurograph.v1.models.personas_persona import PersonasPersona
    from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor
    from neurograph.v1.models.personas_persona_factor_create_request import PersonasPersonaFactorCreateRequest
    from neurograph.v1.models.personas_persona_factor_create_response import PersonasPersonaFactorCreateResponse
    from neurograph.v1.models.personas_persona_factor_resp import PersonasPersonaFactorResp
    from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight
    from neurograph.v1.models.personas_persona_insight_create_request import PersonasPersonaInsightCreateRequest
    from neurograph.v1.models.personas_persona_insight_create_response import PersonasPersonaInsightCreateResponse
    from neurograph.v1.models.personas_persona_instance_create_request import PersonasPersonaInstanceCreateRequest
    from neurograph.v1.models.personas_persona_instance_create_response import PersonasPersonaInstanceCreateResponse
    from neurograph.v1.models.personas_persona_instances_delete_response import PersonasPersonaInstancesDeleteResponse
    from neurograph.v1.models.personas_persona_instances_response import PersonasPersonaInstancesResponse
    from neurograph.v1.models.personas_persona_kpi_create_request import PersonasPersonaKpiCreateRequest
    from neurograph.v1.models.personas_persona_kpi_create_response import PersonasPersonaKpiCreateResponse
    from neurograph.v1.models.personas_persona_kpi_req import PersonasPersonaKpiReq
    from neurograph.v1.models.personas_persona_kpi_resp import PersonasPersonaKpiResp
    from neurograph.v1.models.personas_persona_match_criteria_request import PersonasPersonaMatchCriteriaRequest
    from neurograph.v1.models.personas_persona_match_criteria_response import PersonasPersonaMatchCriteriaResponse
    from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait
    from neurograph.v1.models.personas_persona_seed import PersonasPersonaSeed
    from neurograph.v1.models.personas_persona_seed_create_request import PersonasPersonaSeedCreateRequest
    from neurograph.v1.models.personas_persona_seed_get_many_response import PersonasPersonaSeedGetManyResponse
    from neurograph.v1.models.personas_persona_seeds_delete_request import PersonasPersonaSeedsDeleteRequest
    from neurograph.v1.models.personas_persona_seeds_delete_response import PersonasPersonaSeedsDeleteResponse
    from neurograph.v1.models.personas_persona_trait_create_request import PersonasPersonaTraitCreateRequest
    from neurograph.v1.models.personas_persona_trait_create_response import PersonasPersonaTraitCreateResponse
    from neurograph.v1.models.personas_personality_trait_in import PersonasPersonalityTraitIn
    from neurograph.v1.models.personas_personality_trait_out import PersonasPersonalityTraitOut
    from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier
    from neurograph.v1.models.pgtype_int8 import PgtypeInt8
    from neurograph.v1.models.pgtype_text import PgtypeText
    from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp
    from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest
    from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse
    from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion
    from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse
    from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse
    from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            """# import models into model package
from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest
from neurograph.v1.models.auth_service_token_response import AuthServiceTokenResponse
from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse
from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse
from neurograph.v1.models.client_client import ClientClient
from neurograph.v1.models.client_client_get_detail_response import ClientClientGetDetailResponse
from neurograph.v1.models.client_client_get_many_response import ClientClientGetManyResponse
from neurograph.v1.models.client_client_info import ClientClientInfo
from neurograph.v1.models.client_client_metadata_request import ClientClientMetadataRequest
from neurograph.v1.models.client_client_metadata_response import ClientClientMetadataResponse
from neurograph.v1.models.client_client_personas_response import ClientClientPersonasResponse
from neurograph.v1.models.client_client_url_snapshot_response import ClientClientURLSnapshotResponse
from neurograph.v1.models.client_client_url_snapshot_row import ClientClientURLSnapshotRow
from neurograph.v1.models.client_client_upsert_request import ClientClientUpsertRequest
from neurograph.v1.models.client_client_upsert_response import ClientClientUpsertResponse
from neurograph.v1.models.client_client_url_row import ClientClientUrlRow
from neurograph.v1.models.client_client_url_upsert_request import ClientClientUrlUpsertRequest
from neurograph.v1.models.client_client_url_upsert_response import ClientClientUrlUpsertResponse
from neurograph.v1.models.client_client_urls_response import ClientClientUrlsResponse
from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest
from neurograph.v1.models.client_kpi import ClientKpi
from neurograph.v1.models.client_metadata import ClientMetadata
from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand
from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail
from neurograph.v1.models.client_persona import ClientPersona
from neurograph.v1.models.client_persona_factor import ClientPersonaFactor
from neurograph.v1.models.client_persona_insight import ClientPersonaInsight
from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait
from neurograph.v1.models.client_probe import ClientProbe
from neurograph.v1.models.client_probe_todo_row import ClientProbeTodoRow
from neurograph.v1.models.client_query import ClientQuery
from neurograph.v1.models.client_trigger_probe_response import ClientTriggerProbeResponse
from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig
from neurograph.v1.models.dagster_dagster_info import DagsterDagsterInfo
from neurograph.v1.models.dagster_dagster_log_create_request import DagsterDagsterLogCreateRequest
from neurograph.v1.models.dagster_dagster_log_create_response import DagsterDagsterLogCreateResponse
from neurograph.v1.models.dagster_dagster_log_get_response import DagsterDagsterLogGetResponse
from neurograph.v1.models.db_client_url import DbClientUrl
from neurograph.v1.models.db_knowledge_customer import DbKnowledgeCustomer
from neurograph.v1.models.db_knowledge_order import DbKnowledgeOrder
from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct
from neurograph.v1.models.db_knowledge_store import DbKnowledgeStore
from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams
from neurograph.v1.models.knowledge_assertion import KnowledgeAssertion
from neurograph.v1.models.knowledge_assertion_create_request import KnowledgeAssertionCreateRequest
from neurograph.v1.models.knowledge_assertion_list_response import KnowledgeAssertionListResponse
from neurograph.v1.models.knowledge_assertion_query import KnowledgeAssertionQuery
from neurograph.v1.models.knowledge_assertion_response import KnowledgeAssertionResponse
from neurograph.v1.models.knowledge_customer_query import KnowledgeCustomerQuery
from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse
from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact
from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest
from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse
from neurograph.v1.models.knowledge_enrichment_artifact_response import KnowledgeEnrichmentArtifactResponse
from neurograph.v1.models.knowledge_enrichment_artifact_update_output_request import KnowledgeEnrichmentArtifactUpdateOutputRequest
from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest
from neurograph.v1.models.knowledge_enrichment_query import KnowledgeEnrichmentQuery
from neurograph.v1.models.knowledge_entity import KnowledgeEntity
from neurograph.v1.models.knowledge_entity_create_request import KnowledgeEntityCreateRequest
from neurograph.v1.models.knowledge_entity_create_response import KnowledgeEntityCreateResponse
from neurograph.v1.models.knowledge_entity_extra import KnowledgeEntityExtra
from neurograph.v1.models.knowledge_entity_get_many_response import KnowledgeEntityGetManyResponse
from neurograph.v1.models.knowledge_entity_in_db import KnowledgeEntityInDb
from neurograph.v1.models.knowledge_entity_relations import KnowledgeEntityRelations
from neurograph.v1.models.knowledge_entity_schema import KnowledgeEntitySchema
from neurograph.v1.models.knowledge_entity_schema_row import KnowledgeEntitySchemaRow
from neurograph.v1.models.knowledge_entity_schema_upsert_request import KnowledgeEntitySchemaUpsertRequest
from neurograph.v1.models.knowledge_entity_schemas_response import KnowledgeEntitySchemasResponse
from neurograph.v1.models.knowledge_entity_schemas_upsert_response import KnowledgeEntitySchemasUpsertResponse
from neurograph.v1.models.knowledge_entity_type_row import KnowledgeEntityTypeRow
from neurograph.v1.models.knowledge_entity_upsert_request import KnowledgeEntityUpsertRequest
from neurograph.v1.models.knowledge_entity_upsert_row import KnowledgeEntityUpsertRow
from neurograph.v1.models.knowledge_err_entity_row import KnowledgeErrEntityRow
from neurograph.v1.models.knowledge_ingest_raw_request import KnowledgeIngestRawRequest
from neurograph.v1.models.knowledge_ingest_raw_response import KnowledgeIngestRawResponse
from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow
from neurograph.v1.models.knowledge_kind_response import KnowledgeKindResponse
from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery
from neurograph.v1.models.knowledge_order_response import KnowledgeOrderResponse
from neurograph.v1.models.knowledge_product_query import KnowledgeProductQuery
from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse
from neurograph.v1.models.knowledge_query import KnowledgeQuery
from neurograph.v1.models.knowledge_store_query import KnowledgeStoreQuery
from neurograph.v1.models.knowledge_store_response import KnowledgeStoreResponse
from neurograph.v1.models.knowledge_type_response import KnowledgeTypeResponse
from neurograph.v1.models.lookup_language import LookupLanguage
from neurograph.v1.models.lookup_lookup_language_response import LookupLookupLanguageResponse
from neurograph.v1.models.lookup_lookup_state_response import LookupLookupStateResponse
from neurograph.v1.models.lookup_state import LookupState
from neurograph.v1.models.lookup_state_response import LookupStateResponse
from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse
from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest
from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest
from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse
from neurograph.v1.models.organizations_metadata import OrganizationsMetadata
from neurograph.v1.models.organizations_organization import OrganizationsOrganization
from neurograph.v1.models.organizations_organization_brand import OrganizationsOrganizationBrand
from neurograph.v1.models.organizations_organization_create_request import OrganizationsOrganizationCreateRequest
from neurograph.v1.models.organizations_organization_detail_response import OrganizationsOrganizationDetailResponse
from neurograph.v1.models.organizations_organization_get_many_response import OrganizationsOrganizationGetManyResponse
from neurograph.v1.models.organizations_organization_metadata_request import OrganizationsOrganizationMetadataRequest
from neurograph.v1.models.organizations_organization_metadata_response import OrganizationsOrganizationMetadataResponse
from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest
from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse
from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest
from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig
from neurograph.v1.models.personas_delete_many_persona_instances_request import PersonasDeleteManyPersonaInstancesRequest
from neurograph.v1.models.personas_kpi import PersonasKpi
from neurograph.v1.models.personas_match_criteria_row import PersonasMatchCriteriaRow
from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn
from neurograph.v1.models.personas_persona import PersonasPersona
from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor
from neurograph.v1.models.personas_persona_factor_create_request import PersonasPersonaFactorCreateRequest
from neurograph.v1.models.personas_persona_factor_create_response import PersonasPersonaFactorCreateResponse
from neurograph.v1.models.personas_persona_factor_resp import PersonasPersonaFactorResp
from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight
from neurograph.v1.models.personas_persona_insight_create_request import PersonasPersonaInsightCreateRequest
from neurograph.v1.models.personas_persona_insight_create_response import PersonasPersonaInsightCreateResponse
from neurograph.v1.models.personas_persona_instance_create_request import PersonasPersonaInstanceCreateRequest
from neurograph.v1.models.personas_persona_instance_create_response import PersonasPersonaInstanceCreateResponse
from neurograph.v1.models.personas_persona_instances_delete_response import PersonasPersonaInstancesDeleteResponse
from neurograph.v1.models.personas_persona_instances_response import PersonasPersonaInstancesResponse
from neurograph.v1.models.personas_persona_kpi_create_request import PersonasPersonaKpiCreateRequest
from neurograph.v1.models.personas_persona_kpi_create_response import PersonasPersonaKpiCreateResponse
from neurograph.v1.models.personas_persona_kpi_req import PersonasPersonaKpiReq
from neurograph.v1.models.personas_persona_kpi_resp import PersonasPersonaKpiResp
from neurograph.v1.models.personas_persona_match_criteria_request import PersonasPersonaMatchCriteriaRequest
from neurograph.v1.models.personas_persona_match_criteria_response import PersonasPersonaMatchCriteriaResponse
from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait
from neurograph.v1.models.personas_persona_seed import PersonasPersonaSeed
from neurograph.v1.models.personas_persona_seed_create_request import PersonasPersonaSeedCreateRequest
from neurograph.v1.models.personas_persona_seed_get_many_response import PersonasPersonaSeedGetManyResponse
from neurograph.v1.models.personas_persona_seeds_delete_request import PersonasPersonaSeedsDeleteRequest
from neurograph.v1.models.personas_persona_seeds_delete_response import PersonasPersonaSeedsDeleteResponse
from neurograph.v1.models.personas_persona_trait_create_request import PersonasPersonaTraitCreateRequest
from neurograph.v1.models.personas_persona_trait_create_response import PersonasPersonaTraitCreateResponse
from neurograph.v1.models.personas_personality_trait_in import PersonasPersonalityTraitIn
from neurograph.v1.models.personas_personality_trait_out import PersonasPersonalityTraitOut
from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier
from neurograph.v1.models.pgtype_int8 import PgtypeInt8
from neurograph.v1.models.pgtype_text import PgtypeText
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp
from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest
from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse
from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion
from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse
from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse
from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

# flake8: noqa

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AuthenticationApi",
    "ClientApi",
    "ClientMetadataApi",
    "DagsterApi",
    "KnowledgeApi",
    "KnowledgeExtractApi",
    "LookupApi",
    "OrganizationApi",
    "OrganizationMetadataApi",
    "PersonaApi",
    "SystemApi",
    "WorkbenchApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AuthServiceTokenRequest",
    "AuthServiceTokenResponse",
    "AuthTestServiceTokenRequest",
    "AuthTestServiceTokenResponse",
    "AuthTestTokenResponse",
    "ClientClient",
    "ClientClientGetDetailResponse",
    "ClientClientGetManyResponse",
    "ClientClientInfo",
    "ClientClientMetadataRequest",
    "ClientClientMetadataResponse",
    "ClientClientPersonasResponse",
    "ClientClientURLSnapshotResponse",
    "ClientClientURLSnapshotRow",
    "ClientClientUpsertRequest",
    "ClientClientUpsertResponse",
    "ClientClientUrlRow",
    "ClientClientUrlUpsertRequest",
    "ClientClientUrlUpsertResponse",
    "ClientClientUrlsResponse",
    "ClientDeleteMetadataRequest",
    "ClientKpi",
    "ClientMetadata",
    "ClientOrganizationBrand",
    "ClientOrganizationDetail",
    "ClientPersona",
    "ClientPersonaFactor",
    "ClientPersonaInsight",
    "ClientPersonaPersonalityTrait",
    "ClientProbe",
    "ClientProbeTodoRow",
    "ClientQuery",
    "ClientTriggerProbeResponse",
    "ClientWorkbenchConfig",
    "DagsterDagsterInfo",
    "DagsterDagsterLogCreateRequest",
    "DagsterDagsterLogCreateResponse",
    "DagsterDagsterLogGetResponse",
    "DbClientUrl",
    "DbKnowledgeCustomer",
    "DbKnowledgeOrder",
    "DbKnowledgeProduct",
    "DbKnowledgeStore",
    "DbPersonaFactorCreateParams",
    "KnowledgeAssertion",
    "KnowledgeAssertionCreateRequest",
    "KnowledgeAssertionListResponse",
    "KnowledgeAssertionQuery",
    "KnowledgeAssertionResponse",
    "KnowledgeCustomerQuery",
    "KnowledgeCustomerResponse",
    "KnowledgeEnrichmentArtifact",
    "KnowledgeEnrichmentArtifactCreateRequest",
    "KnowledgeEnrichmentArtifactListResponse",
    "KnowledgeEnrichmentArtifactResponse",
    "KnowledgeEnrichmentArtifactUpdateOutputRequest",
    "KnowledgeEnrichmentArtifactUpdateStatusRequest",
    "KnowledgeEnrichmentQuery",
    "KnowledgeEntity",
    "KnowledgeEntityCreateRequest",
    "KnowledgeEntityCreateResponse",
    "KnowledgeEntityExtra",
    "KnowledgeEntityGetManyResponse",
    "KnowledgeEntityInDb",
    "KnowledgeEntityRelations",
    "KnowledgeEntitySchema",
    "KnowledgeEntitySchemaRow",
    "KnowledgeEntitySchemaUpsertRequest",
    "KnowledgeEntitySchemasResponse",
    "KnowledgeEntitySchemasUpsertResponse",
    "KnowledgeEntityTypeRow",
    "KnowledgeEntityUpsertRequest",
    "KnowledgeEntityUpsertRow",
    "KnowledgeErrEntityRow",
    "KnowledgeIngestRawRequest",
    "KnowledgeIngestRawResponse",
    "KnowledgeIngestRawRow",
    "KnowledgeKindResponse",
    "KnowledgeOrderQuery",
    "KnowledgeOrderResponse",
    "KnowledgeProductQuery",
    "KnowledgeProductResponse",
    "KnowledgeQuery",
    "KnowledgeStoreQuery",
    "KnowledgeStoreResponse",
    "KnowledgeTypeResponse",
    "LookupLanguage",
    "LookupLookupLanguageResponse",
    "LookupLookupStateResponse",
    "LookupState",
    "LookupStateResponse",
    "OrganizationsBrandDetailResponse",
    "OrganizationsBrandUpsertRequest",
    "OrganizationsDeleteMetadataRequest",
    "OrganizationsDeleteMetadataResponse",
    "OrganizationsMetadata",
    "OrganizationsOrganization",
    "OrganizationsOrganizationBrand",
    "OrganizationsOrganizationCreateRequest",
    "OrganizationsOrganizationDetailResponse",
    "OrganizationsOrganizationGetManyResponse",
    "OrganizationsOrganizationMetadataRequest",
    "OrganizationsOrganizationMetadataResponse",
    "OrganizationsOrganizationSetWorkbenchRequest",
    "OrganizationsOrganizationSetWorkbenchResponse",
    "OrganizationsOrganizationUpdateRequest",
    "OrganizationsWorkbenchConfig",
    "PersonasDeleteManyPersonaInstancesRequest",
    "PersonasKpi",
    "PersonasMatchCriteriaRow",
    "PersonasMatchCriteriaRowIn",
    "PersonasPersona",
    "PersonasPersonaFactor",
    "PersonasPersonaFactorCreateRequest",
    "PersonasPersonaFactorCreateResponse",
    "PersonasPersonaFactorResp",
    "PersonasPersonaInsight",
    "PersonasPersonaInsightCreateRequest",
    "PersonasPersonaInsightCreateResponse",
    "PersonasPersonaInstanceCreateRequest",
    "PersonasPersonaInstanceCreateResponse",
    "PersonasPersonaInstancesDeleteResponse",
    "PersonasPersonaInstancesResponse",
    "PersonasPersonaKpiCreateRequest",
    "PersonasPersonaKpiCreateResponse",
    "PersonasPersonaKpiReq",
    "PersonasPersonaKpiResp",
    "PersonasPersonaMatchCriteriaRequest",
    "PersonasPersonaMatchCriteriaResponse",
    "PersonasPersonaPersonalityTrait",
    "PersonasPersonaSeed",
    "PersonasPersonaSeedCreateRequest",
    "PersonasPersonaSeedGetManyResponse",
    "PersonasPersonaSeedsDeleteRequest",
    "PersonasPersonaSeedsDeleteResponse",
    "PersonasPersonaTraitCreateRequest",
    "PersonasPersonaTraitCreateResponse",
    "PersonasPersonalityTraitIn",
    "PersonasPersonalityTraitOut",
    "PgtypeInfinityModifier",
    "PgtypeInt8",
    "PgtypeText",
    "PgtypeTimestamp",
    "WorkbenchWorkbenchUrlCheckRequest",
    "WorkbenchWorkbenchUrlCheckResponse",
    "WorkbenchWorkbenchVersion",
    "WorkbenchWorkbenchVersionManyResponse",
    "WorkbenchWorkbenchVersionResponse",
    "WorkbenchWorkbenchVersionUpsertRequest",
]

if __import__("typing").TYPE_CHECKING:
    # import apis into sdk package
    from neurograph.v1.api.authentication_api import AuthenticationApi as AuthenticationApi
    from neurograph.v1.api.client_api import ClientApi as ClientApi
    from neurograph.v1.api.client_metadata_api import ClientMetadataApi as ClientMetadataApi
    from neurograph.v1.api.dagster_api import DagsterApi as DagsterApi
    from neurograph.v1.api.knowledge_api import KnowledgeApi as KnowledgeApi
    from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi as KnowledgeExtractApi
    from neurograph.v1.api.lookup_api import LookupApi as LookupApi
    from neurograph.v1.api.organization_api import OrganizationApi as OrganizationApi
    from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi as OrganizationMetadataApi
    from neurograph.v1.api.persona_api import PersonaApi as PersonaApi
    from neurograph.v1.api.system_api import SystemApi as SystemApi
    from neurograph.v1.api.workbench_api import WorkbenchApi as WorkbenchApi
    
    # import ApiClient
    from neurograph.v1.api_response import ApiResponse as ApiResponse
    from neurograph.v1.api_client import ApiClient as ApiClient
    from neurograph.v1.configuration import Configuration as Configuration
    from neurograph.v1.exceptions import OpenApiException as OpenApiException
    from neurograph.v1.exceptions import ApiTypeError as ApiTypeError
    from neurograph.v1.exceptions import ApiValueError as ApiValueError
    from neurograph.v1.exceptions import ApiKeyError as ApiKeyError
    from neurograph.v1.exceptions import ApiAttributeError as ApiAttributeError
    from neurograph.v1.exceptions import ApiException as ApiException
    
    # import models into sdk package
    from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest as AuthServiceTokenRequest
    from neurograph.v1.models.auth_service_token_response import AuthServiceTokenResponse as AuthServiceTokenResponse
    from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest as AuthTestServiceTokenRequest
    from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse as AuthTestServiceTokenResponse
    from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse as AuthTestTokenResponse
    from neurograph.v1.models.client_client import ClientClient as ClientClient
    from neurograph.v1.models.client_client_get_detail_response import ClientClientGetDetailResponse as ClientClientGetDetailResponse
    from neurograph.v1.models.client_client_get_many_response import ClientClientGetManyResponse as ClientClientGetManyResponse
    from neurograph.v1.models.client_client_info import ClientClientInfo as ClientClientInfo
    from neurograph.v1.models.client_client_metadata_request import ClientClientMetadataRequest as ClientClientMetadataRequest
    from neurograph.v1.models.client_client_metadata_response import ClientClientMetadataResponse as ClientClientMetadataResponse
    from neurograph.v1.models.client_client_personas_response import ClientClientPersonasResponse as ClientClientPersonasResponse
    from neurograph.v1.models.client_client_url_snapshot_response import ClientClientURLSnapshotResponse as ClientClientURLSnapshotResponse
    from neurograph.v1.models.client_client_url_snapshot_row import ClientClientURLSnapshotRow as ClientClientURLSnapshotRow
    from neurograph.v1.models.client_client_upsert_request import ClientClientUpsertRequest as ClientClientUpsertRequest
    from neurograph.v1.models.client_client_upsert_response import ClientClientUpsertResponse as ClientClientUpsertResponse
    from neurograph.v1.models.client_client_url_row import ClientClientUrlRow as ClientClientUrlRow
    from neurograph.v1.models.client_client_url_upsert_request import ClientClientUrlUpsertRequest as ClientClientUrlUpsertRequest
    from neurograph.v1.models.client_client_url_upsert_response import ClientClientUrlUpsertResponse as ClientClientUrlUpsertResponse
    from neurograph.v1.models.client_client_urls_response import ClientClientUrlsResponse as ClientClientUrlsResponse
    from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest as ClientDeleteMetadataRequest
    from neurograph.v1.models.client_kpi import ClientKpi as ClientKpi
    from neurograph.v1.models.client_metadata import ClientMetadata as ClientMetadata
    from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand as ClientOrganizationBrand
    from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail as ClientOrganizationDetail
    from neurograph.v1.models.client_persona import ClientPersona as ClientPersona
    from neurograph.v1.models.client_persona_factor import ClientPersonaFactor as ClientPersonaFactor
    from neurograph.v1.models.client_persona_insight import ClientPersonaInsight as ClientPersonaInsight
    from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait as ClientPersonaPersonalityTrait
    from neurograph.v1.models.client_probe import ClientProbe as ClientProbe
    from neurograph.v1.models.client_probe_todo_row import ClientProbeTodoRow as ClientProbeTodoRow
    from neurograph.v1.models.client_query import ClientQuery as ClientQuery
    from neurograph.v1.models.client_trigger_probe_response import ClientTriggerProbeResponse as ClientTriggerProbeResponse
    from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig as ClientWorkbenchConfig
    from neurograph.v1.models.dagster_dagster_info import DagsterDagsterInfo as DagsterDagsterInfo
    from neurograph.v1.models.dagster_dagster_log_create_request import DagsterDagsterLogCreateRequest as DagsterDagsterLogCreateRequest
    from neurograph.v1.models.dagster_dagster_log_create_response import DagsterDagsterLogCreateResponse as DagsterDagsterLogCreateResponse
    from neurograph.v1.models.dagster_dagster_log_get_response import DagsterDagsterLogGetResponse as DagsterDagsterLogGetResponse
    from neurograph.v1.models.db_client_url import DbClientUrl as DbClientUrl
    from neurograph.v1.models.db_knowledge_customer import DbKnowledgeCustomer as DbKnowledgeCustomer
    from neurograph.v1.models.db_knowledge_order import DbKnowledgeOrder as DbKnowledgeOrder
    from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct as DbKnowledgeProduct
    from neurograph.v1.models.db_knowledge_store import DbKnowledgeStore as DbKnowledgeStore
    from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams as DbPersonaFactorCreateParams
    from neurograph.v1.models.knowledge_assertion import KnowledgeAssertion as KnowledgeAssertion
    from neurograph.v1.models.knowledge_assertion_create_request import KnowledgeAssertionCreateRequest as KnowledgeAssertionCreateRequest
    from neurograph.v1.models.knowledge_assertion_list_response import KnowledgeAssertionListResponse as KnowledgeAssertionListResponse
    from neurograph.v1.models.knowledge_assertion_query import KnowledgeAssertionQuery as KnowledgeAssertionQuery
    from neurograph.v1.models.knowledge_assertion_response import KnowledgeAssertionResponse as KnowledgeAssertionResponse
    from neurograph.v1.models.knowledge_customer_query import KnowledgeCustomerQuery as KnowledgeCustomerQuery
    from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse as KnowledgeCustomerResponse
    from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact as KnowledgeEnrichmentArtifact
    from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest as KnowledgeEnrichmentArtifactCreateRequest
    from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse as KnowledgeEnrichmentArtifactListResponse
    from neurograph.v1.models.knowledge_enrichment_artifact_response import KnowledgeEnrichmentArtifactResponse as KnowledgeEnrichmentArtifactResponse
    from neurograph.v1.models.knowledge_enrichment_artifact_update_output_request import KnowledgeEnrichmentArtifactUpdateOutputRequest as KnowledgeEnrichmentArtifactUpdateOutputRequest
    from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest as KnowledgeEnrichmentArtifactUpdateStatusRequest
    from neurograph.v1.models.knowledge_enrichment_query import KnowledgeEnrichmentQuery as KnowledgeEnrichmentQuery
    from neurograph.v1.models.knowledge_entity import KnowledgeEntity as KnowledgeEntity
    from neurograph.v1.models.knowledge_entity_create_request import KnowledgeEntityCreateRequest as KnowledgeEntityCreateRequest
    from neurograph.v1.models.knowledge_entity_create_response import KnowledgeEntityCreateResponse as KnowledgeEntityCreateResponse
    from neurograph.v1.models.knowledge_entity_extra import KnowledgeEntityExtra as KnowledgeEntityExtra
    from neurograph.v1.models.knowledge_entity_get_many_response import KnowledgeEntityGetManyResponse as KnowledgeEntityGetManyResponse
    from neurograph.v1.models.knowledge_entity_in_db import KnowledgeEntityInDb as KnowledgeEntityInDb
    from neurograph.v1.models.knowledge_entity_relations import KnowledgeEntityRelations as KnowledgeEntityRelations
    from neurograph.v1.models.knowledge_entity_schema import KnowledgeEntitySchema as KnowledgeEntitySchema
    from neurograph.v1.models.knowledge_entity_schema_row import KnowledgeEntitySchemaRow as KnowledgeEntitySchemaRow
    from neurograph.v1.models.knowledge_entity_schema_upsert_request import KnowledgeEntitySchemaUpsertRequest as KnowledgeEntitySchemaUpsertRequest
    from neurograph.v1.models.knowledge_entity_schemas_response import KnowledgeEntitySchemasResponse as KnowledgeEntitySchemasResponse
    from neurograph.v1.models.knowledge_entity_schemas_upsert_response import KnowledgeEntitySchemasUpsertResponse as KnowledgeEntitySchemasUpsertResponse
    from neurograph.v1.models.knowledge_entity_type_row import KnowledgeEntityTypeRow as KnowledgeEntityTypeRow
    from neurograph.v1.models.knowledge_entity_upsert_request import KnowledgeEntityUpsertRequest as KnowledgeEntityUpsertRequest
    from neurograph.v1.models.knowledge_entity_upsert_row import KnowledgeEntityUpsertRow as KnowledgeEntityUpsertRow
    from neurograph.v1.models.knowledge_err_entity_row import KnowledgeErrEntityRow as KnowledgeErrEntityRow
    from neurograph.v1.models.knowledge_ingest_raw_request import KnowledgeIngestRawRequest as KnowledgeIngestRawRequest
    from neurograph.v1.models.knowledge_ingest_raw_response import KnowledgeIngestRawResponse as KnowledgeIngestRawResponse
    from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow as KnowledgeIngestRawRow
    from neurograph.v1.models.knowledge_kind_response import KnowledgeKindResponse as KnowledgeKindResponse
    from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery as KnowledgeOrderQuery
    from neurograph.v1.models.knowledge_order_response import KnowledgeOrderResponse as KnowledgeOrderResponse
    from neurograph.v1.models.knowledge_product_query import KnowledgeProductQuery as KnowledgeProductQuery
    from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse as KnowledgeProductResponse
    from neurograph.v1.models.knowledge_query import KnowledgeQuery as KnowledgeQuery
    from neurograph.v1.models.knowledge_store_query import KnowledgeStoreQuery as KnowledgeStoreQuery
    from neurograph.v1.models.knowledge_store_response import KnowledgeStoreResponse as KnowledgeStoreResponse
    from neurograph.v1.models.knowledge_type_response import KnowledgeTypeResponse as KnowledgeTypeResponse
    from neurograph.v1.models.lookup_language import LookupLanguage as LookupLanguage
    from neurograph.v1.models.lookup_lookup_language_response import LookupLookupLanguageResponse as LookupLookupLanguageResponse
    from neurograph.v1.models.lookup_lookup_state_response import LookupLookupStateResponse as LookupLookupStateResponse
    from neurograph.v1.models.lookup_state import LookupState as LookupState
    from neurograph.v1.models.lookup_state_response import LookupStateResponse as LookupStateResponse
    from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse as OrganizationsBrandDetailResponse
    from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest as OrganizationsBrandUpsertRequest
    from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest as OrganizationsDeleteMetadataRequest
    from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse as OrganizationsDeleteMetadataResponse
    from neurograph.v1.models.organizations_metadata import OrganizationsMetadata as OrganizationsMetadata
    from neurograph.v1.models.organizations_organization import OrganizationsOrganization as OrganizationsOrganization
    from neurograph.v1.models.organizations_organization_brand import OrganizationsOrganizationBrand as OrganizationsOrganizationBrand
    from neurograph.v1.models.organizations_organization_create_request import OrganizationsOrganizationCreateRequest as OrganizationsOrganizationCreateRequest
    from neurograph.v1.models.organizations_organization_detail_response import OrganizationsOrganizationDetailResponse as OrganizationsOrganizationDetailResponse
    from neurograph.v1.models.organizations_organization_get_many_response import OrganizationsOrganizationGetManyResponse as OrganizationsOrganizationGetManyResponse
    from neurograph.v1.models.organizations_organization_metadata_request import OrganizationsOrganizationMetadataRequest as OrganizationsOrganizationMetadataRequest
    from neurograph.v1.models.organizations_organization_metadata_response import OrganizationsOrganizationMetadataResponse as OrganizationsOrganizationMetadataResponse
    from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest as OrganizationsOrganizationSetWorkbenchRequest
    from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse as OrganizationsOrganizationSetWorkbenchResponse
    from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest as OrganizationsOrganizationUpdateRequest
    from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig as OrganizationsWorkbenchConfig
    from neurograph.v1.models.personas_delete_many_persona_instances_request import PersonasDeleteManyPersonaInstancesRequest as PersonasDeleteManyPersonaInstancesRequest
    from neurograph.v1.models.personas_kpi import PersonasKpi as PersonasKpi
    from neurograph.v1.models.personas_match_criteria_row import PersonasMatchCriteriaRow as PersonasMatchCriteriaRow
    from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn as PersonasMatchCriteriaRowIn
    from neurograph.v1.models.personas_persona import PersonasPersona as PersonasPersona
    from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor as PersonasPersonaFactor
    from neurograph.v1.models.personas_persona_factor_create_request import PersonasPersonaFactorCreateRequest as PersonasPersonaFactorCreateRequest
    from neurograph.v1.models.personas_persona_factor_create_response import PersonasPersonaFactorCreateResponse as PersonasPersonaFactorCreateResponse
    from neurograph.v1.models.personas_persona_factor_resp import PersonasPersonaFactorResp as PersonasPersonaFactorResp
    from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight as PersonasPersonaInsight
    from neurograph.v1.models.personas_persona_insight_create_request import PersonasPersonaInsightCreateRequest as PersonasPersonaInsightCreateRequest
    from neurograph.v1.models.personas_persona_insight_create_response import PersonasPersonaInsightCreateResponse as PersonasPersonaInsightCreateResponse
    from neurograph.v1.models.personas_persona_instance_create_request import PersonasPersonaInstanceCreateRequest as PersonasPersonaInstanceCreateRequest
    from neurograph.v1.models.personas_persona_instance_create_response import PersonasPersonaInstanceCreateResponse as PersonasPersonaInstanceCreateResponse
    from neurograph.v1.models.personas_persona_instances_delete_response import PersonasPersonaInstancesDeleteResponse as PersonasPersonaInstancesDeleteResponse
    from neurograph.v1.models.personas_persona_instances_response import PersonasPersonaInstancesResponse as PersonasPersonaInstancesResponse
    from neurograph.v1.models.personas_persona_kpi_create_request import PersonasPersonaKpiCreateRequest as PersonasPersonaKpiCreateRequest
    from neurograph.v1.models.personas_persona_kpi_create_response import PersonasPersonaKpiCreateResponse as PersonasPersonaKpiCreateResponse
    from neurograph.v1.models.personas_persona_kpi_req import PersonasPersonaKpiReq as PersonasPersonaKpiReq
    from neurograph.v1.models.personas_persona_kpi_resp import PersonasPersonaKpiResp as PersonasPersonaKpiResp
    from neurograph.v1.models.personas_persona_match_criteria_request import PersonasPersonaMatchCriteriaRequest as PersonasPersonaMatchCriteriaRequest
    from neurograph.v1.models.personas_persona_match_criteria_response import PersonasPersonaMatchCriteriaResponse as PersonasPersonaMatchCriteriaResponse
    from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait as PersonasPersonaPersonalityTrait
    from neurograph.v1.models.personas_persona_seed import PersonasPersonaSeed as PersonasPersonaSeed
    from neurograph.v1.models.personas_persona_seed_create_request import PersonasPersonaSeedCreateRequest as PersonasPersonaSeedCreateRequest
    from neurograph.v1.models.personas_persona_seed_get_many_response import PersonasPersonaSeedGetManyResponse as PersonasPersonaSeedGetManyResponse
    from neurograph.v1.models.personas_persona_seeds_delete_request import PersonasPersonaSeedsDeleteRequest as PersonasPersonaSeedsDeleteRequest
    from neurograph.v1.models.personas_persona_seeds_delete_response import PersonasPersonaSeedsDeleteResponse as PersonasPersonaSeedsDeleteResponse
    from neurograph.v1.models.personas_persona_trait_create_request import PersonasPersonaTraitCreateRequest as PersonasPersonaTraitCreateRequest
    from neurograph.v1.models.personas_persona_trait_create_response import PersonasPersonaTraitCreateResponse as PersonasPersonaTraitCreateResponse
    from neurograph.v1.models.personas_personality_trait_in import PersonasPersonalityTraitIn as PersonasPersonalityTraitIn
    from neurograph.v1.models.personas_personality_trait_out import PersonasPersonalityTraitOut as PersonasPersonalityTraitOut
    from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier as PgtypeInfinityModifier
    from neurograph.v1.models.pgtype_int8 import PgtypeInt8 as PgtypeInt8
    from neurograph.v1.models.pgtype_text import PgtypeText as PgtypeText
    from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp as PgtypeTimestamp
    from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest as WorkbenchWorkbenchUrlCheckRequest
    from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse as WorkbenchWorkbenchUrlCheckResponse
    from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion as WorkbenchWorkbenchVersion
    from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse as WorkbenchWorkbenchVersionManyResponse
    from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse as WorkbenchWorkbenchVersionResponse
    from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest as WorkbenchWorkbenchVersionUpsertRequest
    
else:
    from lazy_imports import LazyModule, as_package, load

    load(
        LazyModule(
            *as_package(__file__),
            ("__version__", __version__),
            ("__all__", __all__),
            """# import apis into sdk package
from neurograph.v1.api.authentication_api import AuthenticationApi as AuthenticationApi
from neurograph.v1.api.client_api import ClientApi as ClientApi
from neurograph.v1.api.client_metadata_api import ClientMetadataApi as ClientMetadataApi
from neurograph.v1.api.dagster_api import DagsterApi as DagsterApi
from neurograph.v1.api.knowledge_api import KnowledgeApi as KnowledgeApi
from neurograph.v1.api.knowledge_extract_api import KnowledgeExtractApi as KnowledgeExtractApi
from neurograph.v1.api.lookup_api import LookupApi as LookupApi
from neurograph.v1.api.organization_api import OrganizationApi as OrganizationApi
from neurograph.v1.api.organization_metadata_api import OrganizationMetadataApi as OrganizationMetadataApi
from neurograph.v1.api.persona_api import PersonaApi as PersonaApi
from neurograph.v1.api.system_api import SystemApi as SystemApi
from neurograph.v1.api.workbench_api import WorkbenchApi as WorkbenchApi

# import ApiClient
from neurograph.v1.api_response import ApiResponse as ApiResponse
from neurograph.v1.api_client import ApiClient as ApiClient
from neurograph.v1.configuration import Configuration as Configuration
from neurograph.v1.exceptions import OpenApiException as OpenApiException
from neurograph.v1.exceptions import ApiTypeError as ApiTypeError
from neurograph.v1.exceptions import ApiValueError as ApiValueError
from neurograph.v1.exceptions import ApiKeyError as ApiKeyError
from neurograph.v1.exceptions import ApiAttributeError as ApiAttributeError
from neurograph.v1.exceptions import ApiException as ApiException

# import models into sdk package
from neurograph.v1.models.auth_service_token_request import AuthServiceTokenRequest as AuthServiceTokenRequest
from neurograph.v1.models.auth_service_token_response import AuthServiceTokenResponse as AuthServiceTokenResponse
from neurograph.v1.models.auth_test_service_token_request import AuthTestServiceTokenRequest as AuthTestServiceTokenRequest
from neurograph.v1.models.auth_test_service_token_response import AuthTestServiceTokenResponse as AuthTestServiceTokenResponse
from neurograph.v1.models.auth_test_token_response import AuthTestTokenResponse as AuthTestTokenResponse
from neurograph.v1.models.client_client import ClientClient as ClientClient
from neurograph.v1.models.client_client_get_detail_response import ClientClientGetDetailResponse as ClientClientGetDetailResponse
from neurograph.v1.models.client_client_get_many_response import ClientClientGetManyResponse as ClientClientGetManyResponse
from neurograph.v1.models.client_client_info import ClientClientInfo as ClientClientInfo
from neurograph.v1.models.client_client_metadata_request import ClientClientMetadataRequest as ClientClientMetadataRequest
from neurograph.v1.models.client_client_metadata_response import ClientClientMetadataResponse as ClientClientMetadataResponse
from neurograph.v1.models.client_client_personas_response import ClientClientPersonasResponse as ClientClientPersonasResponse
from neurograph.v1.models.client_client_url_snapshot_response import ClientClientURLSnapshotResponse as ClientClientURLSnapshotResponse
from neurograph.v1.models.client_client_url_snapshot_row import ClientClientURLSnapshotRow as ClientClientURLSnapshotRow
from neurograph.v1.models.client_client_upsert_request import ClientClientUpsertRequest as ClientClientUpsertRequest
from neurograph.v1.models.client_client_upsert_response import ClientClientUpsertResponse as ClientClientUpsertResponse
from neurograph.v1.models.client_client_url_row import ClientClientUrlRow as ClientClientUrlRow
from neurograph.v1.models.client_client_url_upsert_request import ClientClientUrlUpsertRequest as ClientClientUrlUpsertRequest
from neurograph.v1.models.client_client_url_upsert_response import ClientClientUrlUpsertResponse as ClientClientUrlUpsertResponse
from neurograph.v1.models.client_client_urls_response import ClientClientUrlsResponse as ClientClientUrlsResponse
from neurograph.v1.models.client_delete_metadata_request import ClientDeleteMetadataRequest as ClientDeleteMetadataRequest
from neurograph.v1.models.client_kpi import ClientKpi as ClientKpi
from neurograph.v1.models.client_metadata import ClientMetadata as ClientMetadata
from neurograph.v1.models.client_organization_brand import ClientOrganizationBrand as ClientOrganizationBrand
from neurograph.v1.models.client_organization_detail import ClientOrganizationDetail as ClientOrganizationDetail
from neurograph.v1.models.client_persona import ClientPersona as ClientPersona
from neurograph.v1.models.client_persona_factor import ClientPersonaFactor as ClientPersonaFactor
from neurograph.v1.models.client_persona_insight import ClientPersonaInsight as ClientPersonaInsight
from neurograph.v1.models.client_persona_personality_trait import ClientPersonaPersonalityTrait as ClientPersonaPersonalityTrait
from neurograph.v1.models.client_probe import ClientProbe as ClientProbe
from neurograph.v1.models.client_probe_todo_row import ClientProbeTodoRow as ClientProbeTodoRow
from neurograph.v1.models.client_query import ClientQuery as ClientQuery
from neurograph.v1.models.client_trigger_probe_response import ClientTriggerProbeResponse as ClientTriggerProbeResponse
from neurograph.v1.models.client_workbench_config import ClientWorkbenchConfig as ClientWorkbenchConfig
from neurograph.v1.models.dagster_dagster_info import DagsterDagsterInfo as DagsterDagsterInfo
from neurograph.v1.models.dagster_dagster_log_create_request import DagsterDagsterLogCreateRequest as DagsterDagsterLogCreateRequest
from neurograph.v1.models.dagster_dagster_log_create_response import DagsterDagsterLogCreateResponse as DagsterDagsterLogCreateResponse
from neurograph.v1.models.dagster_dagster_log_get_response import DagsterDagsterLogGetResponse as DagsterDagsterLogGetResponse
from neurograph.v1.models.db_client_url import DbClientUrl as DbClientUrl
from neurograph.v1.models.db_knowledge_customer import DbKnowledgeCustomer as DbKnowledgeCustomer
from neurograph.v1.models.db_knowledge_order import DbKnowledgeOrder as DbKnowledgeOrder
from neurograph.v1.models.db_knowledge_product import DbKnowledgeProduct as DbKnowledgeProduct
from neurograph.v1.models.db_knowledge_store import DbKnowledgeStore as DbKnowledgeStore
from neurograph.v1.models.db_persona_factor_create_params import DbPersonaFactorCreateParams as DbPersonaFactorCreateParams
from neurograph.v1.models.knowledge_assertion import KnowledgeAssertion as KnowledgeAssertion
from neurograph.v1.models.knowledge_assertion_create_request import KnowledgeAssertionCreateRequest as KnowledgeAssertionCreateRequest
from neurograph.v1.models.knowledge_assertion_list_response import KnowledgeAssertionListResponse as KnowledgeAssertionListResponse
from neurograph.v1.models.knowledge_assertion_query import KnowledgeAssertionQuery as KnowledgeAssertionQuery
from neurograph.v1.models.knowledge_assertion_response import KnowledgeAssertionResponse as KnowledgeAssertionResponse
from neurograph.v1.models.knowledge_customer_query import KnowledgeCustomerQuery as KnowledgeCustomerQuery
from neurograph.v1.models.knowledge_customer_response import KnowledgeCustomerResponse as KnowledgeCustomerResponse
from neurograph.v1.models.knowledge_enrichment_artifact import KnowledgeEnrichmentArtifact as KnowledgeEnrichmentArtifact
from neurograph.v1.models.knowledge_enrichment_artifact_create_request import KnowledgeEnrichmentArtifactCreateRequest as KnowledgeEnrichmentArtifactCreateRequest
from neurograph.v1.models.knowledge_enrichment_artifact_list_response import KnowledgeEnrichmentArtifactListResponse as KnowledgeEnrichmentArtifactListResponse
from neurograph.v1.models.knowledge_enrichment_artifact_response import KnowledgeEnrichmentArtifactResponse as KnowledgeEnrichmentArtifactResponse
from neurograph.v1.models.knowledge_enrichment_artifact_update_output_request import KnowledgeEnrichmentArtifactUpdateOutputRequest as KnowledgeEnrichmentArtifactUpdateOutputRequest
from neurograph.v1.models.knowledge_enrichment_artifact_update_status_request import KnowledgeEnrichmentArtifactUpdateStatusRequest as KnowledgeEnrichmentArtifactUpdateStatusRequest
from neurograph.v1.models.knowledge_enrichment_query import KnowledgeEnrichmentQuery as KnowledgeEnrichmentQuery
from neurograph.v1.models.knowledge_entity import KnowledgeEntity as KnowledgeEntity
from neurograph.v1.models.knowledge_entity_create_request import KnowledgeEntityCreateRequest as KnowledgeEntityCreateRequest
from neurograph.v1.models.knowledge_entity_create_response import KnowledgeEntityCreateResponse as KnowledgeEntityCreateResponse
from neurograph.v1.models.knowledge_entity_extra import KnowledgeEntityExtra as KnowledgeEntityExtra
from neurograph.v1.models.knowledge_entity_get_many_response import KnowledgeEntityGetManyResponse as KnowledgeEntityGetManyResponse
from neurograph.v1.models.knowledge_entity_in_db import KnowledgeEntityInDb as KnowledgeEntityInDb
from neurograph.v1.models.knowledge_entity_relations import KnowledgeEntityRelations as KnowledgeEntityRelations
from neurograph.v1.models.knowledge_entity_schema import KnowledgeEntitySchema as KnowledgeEntitySchema
from neurograph.v1.models.knowledge_entity_schema_row import KnowledgeEntitySchemaRow as KnowledgeEntitySchemaRow
from neurograph.v1.models.knowledge_entity_schema_upsert_request import KnowledgeEntitySchemaUpsertRequest as KnowledgeEntitySchemaUpsertRequest
from neurograph.v1.models.knowledge_entity_schemas_response import KnowledgeEntitySchemasResponse as KnowledgeEntitySchemasResponse
from neurograph.v1.models.knowledge_entity_schemas_upsert_response import KnowledgeEntitySchemasUpsertResponse as KnowledgeEntitySchemasUpsertResponse
from neurograph.v1.models.knowledge_entity_type_row import KnowledgeEntityTypeRow as KnowledgeEntityTypeRow
from neurograph.v1.models.knowledge_entity_upsert_request import KnowledgeEntityUpsertRequest as KnowledgeEntityUpsertRequest
from neurograph.v1.models.knowledge_entity_upsert_row import KnowledgeEntityUpsertRow as KnowledgeEntityUpsertRow
from neurograph.v1.models.knowledge_err_entity_row import KnowledgeErrEntityRow as KnowledgeErrEntityRow
from neurograph.v1.models.knowledge_ingest_raw_request import KnowledgeIngestRawRequest as KnowledgeIngestRawRequest
from neurograph.v1.models.knowledge_ingest_raw_response import KnowledgeIngestRawResponse as KnowledgeIngestRawResponse
from neurograph.v1.models.knowledge_ingest_raw_row import KnowledgeIngestRawRow as KnowledgeIngestRawRow
from neurograph.v1.models.knowledge_kind_response import KnowledgeKindResponse as KnowledgeKindResponse
from neurograph.v1.models.knowledge_order_query import KnowledgeOrderQuery as KnowledgeOrderQuery
from neurograph.v1.models.knowledge_order_response import KnowledgeOrderResponse as KnowledgeOrderResponse
from neurograph.v1.models.knowledge_product_query import KnowledgeProductQuery as KnowledgeProductQuery
from neurograph.v1.models.knowledge_product_response import KnowledgeProductResponse as KnowledgeProductResponse
from neurograph.v1.models.knowledge_query import KnowledgeQuery as KnowledgeQuery
from neurograph.v1.models.knowledge_store_query import KnowledgeStoreQuery as KnowledgeStoreQuery
from neurograph.v1.models.knowledge_store_response import KnowledgeStoreResponse as KnowledgeStoreResponse
from neurograph.v1.models.knowledge_type_response import KnowledgeTypeResponse as KnowledgeTypeResponse
from neurograph.v1.models.lookup_language import LookupLanguage as LookupLanguage
from neurograph.v1.models.lookup_lookup_language_response import LookupLookupLanguageResponse as LookupLookupLanguageResponse
from neurograph.v1.models.lookup_lookup_state_response import LookupLookupStateResponse as LookupLookupStateResponse
from neurograph.v1.models.lookup_state import LookupState as LookupState
from neurograph.v1.models.lookup_state_response import LookupStateResponse as LookupStateResponse
from neurograph.v1.models.organizations_brand_detail_response import OrganizationsBrandDetailResponse as OrganizationsBrandDetailResponse
from neurograph.v1.models.organizations_brand_upsert_request import OrganizationsBrandUpsertRequest as OrganizationsBrandUpsertRequest
from neurograph.v1.models.organizations_delete_metadata_request import OrganizationsDeleteMetadataRequest as OrganizationsDeleteMetadataRequest
from neurograph.v1.models.organizations_delete_metadata_response import OrganizationsDeleteMetadataResponse as OrganizationsDeleteMetadataResponse
from neurograph.v1.models.organizations_metadata import OrganizationsMetadata as OrganizationsMetadata
from neurograph.v1.models.organizations_organization import OrganizationsOrganization as OrganizationsOrganization
from neurograph.v1.models.organizations_organization_brand import OrganizationsOrganizationBrand as OrganizationsOrganizationBrand
from neurograph.v1.models.organizations_organization_create_request import OrganizationsOrganizationCreateRequest as OrganizationsOrganizationCreateRequest
from neurograph.v1.models.organizations_organization_detail_response import OrganizationsOrganizationDetailResponse as OrganizationsOrganizationDetailResponse
from neurograph.v1.models.organizations_organization_get_many_response import OrganizationsOrganizationGetManyResponse as OrganizationsOrganizationGetManyResponse
from neurograph.v1.models.organizations_organization_metadata_request import OrganizationsOrganizationMetadataRequest as OrganizationsOrganizationMetadataRequest
from neurograph.v1.models.organizations_organization_metadata_response import OrganizationsOrganizationMetadataResponse as OrganizationsOrganizationMetadataResponse
from neurograph.v1.models.organizations_organization_set_workbench_request import OrganizationsOrganizationSetWorkbenchRequest as OrganizationsOrganizationSetWorkbenchRequest
from neurograph.v1.models.organizations_organization_set_workbench_response import OrganizationsOrganizationSetWorkbenchResponse as OrganizationsOrganizationSetWorkbenchResponse
from neurograph.v1.models.organizations_organization_update_request import OrganizationsOrganizationUpdateRequest as OrganizationsOrganizationUpdateRequest
from neurograph.v1.models.organizations_workbench_config import OrganizationsWorkbenchConfig as OrganizationsWorkbenchConfig
from neurograph.v1.models.personas_delete_many_persona_instances_request import PersonasDeleteManyPersonaInstancesRequest as PersonasDeleteManyPersonaInstancesRequest
from neurograph.v1.models.personas_kpi import PersonasKpi as PersonasKpi
from neurograph.v1.models.personas_match_criteria_row import PersonasMatchCriteriaRow as PersonasMatchCriteriaRow
from neurograph.v1.models.personas_match_criteria_row_in import PersonasMatchCriteriaRowIn as PersonasMatchCriteriaRowIn
from neurograph.v1.models.personas_persona import PersonasPersona as PersonasPersona
from neurograph.v1.models.personas_persona_factor import PersonasPersonaFactor as PersonasPersonaFactor
from neurograph.v1.models.personas_persona_factor_create_request import PersonasPersonaFactorCreateRequest as PersonasPersonaFactorCreateRequest
from neurograph.v1.models.personas_persona_factor_create_response import PersonasPersonaFactorCreateResponse as PersonasPersonaFactorCreateResponse
from neurograph.v1.models.personas_persona_factor_resp import PersonasPersonaFactorResp as PersonasPersonaFactorResp
from neurograph.v1.models.personas_persona_insight import PersonasPersonaInsight as PersonasPersonaInsight
from neurograph.v1.models.personas_persona_insight_create_request import PersonasPersonaInsightCreateRequest as PersonasPersonaInsightCreateRequest
from neurograph.v1.models.personas_persona_insight_create_response import PersonasPersonaInsightCreateResponse as PersonasPersonaInsightCreateResponse
from neurograph.v1.models.personas_persona_instance_create_request import PersonasPersonaInstanceCreateRequest as PersonasPersonaInstanceCreateRequest
from neurograph.v1.models.personas_persona_instance_create_response import PersonasPersonaInstanceCreateResponse as PersonasPersonaInstanceCreateResponse
from neurograph.v1.models.personas_persona_instances_delete_response import PersonasPersonaInstancesDeleteResponse as PersonasPersonaInstancesDeleteResponse
from neurograph.v1.models.personas_persona_instances_response import PersonasPersonaInstancesResponse as PersonasPersonaInstancesResponse
from neurograph.v1.models.personas_persona_kpi_create_request import PersonasPersonaKpiCreateRequest as PersonasPersonaKpiCreateRequest
from neurograph.v1.models.personas_persona_kpi_create_response import PersonasPersonaKpiCreateResponse as PersonasPersonaKpiCreateResponse
from neurograph.v1.models.personas_persona_kpi_req import PersonasPersonaKpiReq as PersonasPersonaKpiReq
from neurograph.v1.models.personas_persona_kpi_resp import PersonasPersonaKpiResp as PersonasPersonaKpiResp
from neurograph.v1.models.personas_persona_match_criteria_request import PersonasPersonaMatchCriteriaRequest as PersonasPersonaMatchCriteriaRequest
from neurograph.v1.models.personas_persona_match_criteria_response import PersonasPersonaMatchCriteriaResponse as PersonasPersonaMatchCriteriaResponse
from neurograph.v1.models.personas_persona_personality_trait import PersonasPersonaPersonalityTrait as PersonasPersonaPersonalityTrait
from neurograph.v1.models.personas_persona_seed import PersonasPersonaSeed as PersonasPersonaSeed
from neurograph.v1.models.personas_persona_seed_create_request import PersonasPersonaSeedCreateRequest as PersonasPersonaSeedCreateRequest
from neurograph.v1.models.personas_persona_seed_get_many_response import PersonasPersonaSeedGetManyResponse as PersonasPersonaSeedGetManyResponse
from neurograph.v1.models.personas_persona_seeds_delete_request import PersonasPersonaSeedsDeleteRequest as PersonasPersonaSeedsDeleteRequest
from neurograph.v1.models.personas_persona_seeds_delete_response import PersonasPersonaSeedsDeleteResponse as PersonasPersonaSeedsDeleteResponse
from neurograph.v1.models.personas_persona_trait_create_request import PersonasPersonaTraitCreateRequest as PersonasPersonaTraitCreateRequest
from neurograph.v1.models.personas_persona_trait_create_response import PersonasPersonaTraitCreateResponse as PersonasPersonaTraitCreateResponse
from neurograph.v1.models.personas_personality_trait_in import PersonasPersonalityTraitIn as PersonasPersonalityTraitIn
from neurograph.v1.models.personas_personality_trait_out import PersonasPersonalityTraitOut as PersonasPersonalityTraitOut
from neurograph.v1.models.pgtype_infinity_modifier import PgtypeInfinityModifier as PgtypeInfinityModifier
from neurograph.v1.models.pgtype_int8 import PgtypeInt8 as PgtypeInt8
from neurograph.v1.models.pgtype_text import PgtypeText as PgtypeText
from neurograph.v1.models.pgtype_timestamp import PgtypeTimestamp as PgtypeTimestamp
from neurograph.v1.models.workbench_workbench_url_check_request import WorkbenchWorkbenchUrlCheckRequest as WorkbenchWorkbenchUrlCheckRequest
from neurograph.v1.models.workbench_workbench_url_check_response import WorkbenchWorkbenchUrlCheckResponse as WorkbenchWorkbenchUrlCheckResponse
from neurograph.v1.models.workbench_workbench_version import WorkbenchWorkbenchVersion as WorkbenchWorkbenchVersion
from neurograph.v1.models.workbench_workbench_version_many_response import WorkbenchWorkbenchVersionManyResponse as WorkbenchWorkbenchVersionManyResponse
from neurograph.v1.models.workbench_workbench_version_response import WorkbenchWorkbenchVersionResponse as WorkbenchWorkbenchVersionResponse
from neurograph.v1.models.workbench_workbench_version_upsert_request import WorkbenchWorkbenchVersionUpsertRequest as WorkbenchWorkbenchVersionUpsertRequest

""",
            name=__name__,
            doc=__doc__,
        )
    )



# coding: utf-8

"""
    Neurograph Core

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from neurograph.v1.models.client_client_url_row import ClientClientUrlRow

class TestClientClientUrlRow(unittest.TestCase):
    """ClientClientUrlRow unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ClientClientUrlRow:
        """Test ClientClientUrlRow
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ClientClientUrlRow`
        """
        model = ClientClientUrlRow()
        if include_optional:
            return ClientClientUrlRow(
                client_id = 'cli_12345',
                customer_environment = '',
                id = 56,
                is_active = True,
                probes = [
                    neurograph.v1.models.client/probe.client.Probe(
                        error = '', 
                        final_url = '', 
                        has_snapshot = True, 
                        id = '', 
                        is_ok = True, 
                        method = '', 
                        requested_url = '', 
                        response_ms = 56, 
                        status_code = 56, 
                        ts_checked = 56, )
                    ],
                ts_created = 56,
                url = 'example.com'
            )
        else:
            return ClientClientUrlRow(
        )
        """

    def testClientClientUrlRow(self):
        """Test ClientClientUrlRow"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
